/*
 *  KCHMSetupDialog_impl.h
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 */
 
#ifndef KCHMSETUPDIALOG_IMPL_H
#define KCHMSETUPDIALOG_IMPL_H

#include <kchmsetupdialog.h>

class KCHMSetupDialog_impl : public KCHMSetupDialog
{
    TQ_OBJECT

public:
    KCHMSetupDialog_impl( TQWidget* parent = 0, const char* name = 0, bool modal = false, WFlags fl = 0 );

public slots:
    void slotShowHelp();
};

#endif // KCHMSETUPDIALOG_IMPL_H
